[packages/pldnotify] do not skip name and version macros

glen glen at pld-linux.org
Mon Dec 14 22:23:36 CET 2015


commit 770601cf13373bbe8732270ecf6cffb11f8aa26d
Author: Elan Ruusamäe <glen at delfi.ee>
Date:   Mon Dec 14 23:23:13 2015 +0200

    do not skip name and version macros
    
    testcase: php-Smarty.spec

 pldnotify.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/pldnotify.py b/pldnotify.py
index 1fab5c8..a7ceb36 100755
--- a/pldnotify.py
+++ b/pldnotify.py
@@ -37,8 +37,8 @@ class RPMSpec:
                 # skip functions
                 if 'opts' in macro:
                     continue
-                # skip unused macros
-                if macro['used'] <= 0:
+                # skip unused macros, except name and version
+                if macro['used'] <= 0 and (key not in ['name', 'version']):
                     continue
                 macros[key] = macro['body']
             self._macros = macros
================================================================

---- gitweb:

http://git.pld-linux.org/gitweb.cgi/packages/pldnotify.git/commitdiff/770601cf13373bbe8732270ecf6cffb11f8aa26d



More information about the pld-cvs-commit mailing list